@@ -242,7 +242,7 @@ impl ClientFactory for HttpClientFactory {
 
 pub struct Crawler {
 	networking_profile: config::ResolvedNetworkingProfile,
-	parse_tx:           Sender<ParserTask>,
+	tx_pp:              Arc<Sender<ParserTask>>,
 }
 
 pub struct CrawlerIter<JS: JobStateValues, TS: TaskStateValues> {
@@ -275,8 +275,8 @@ impl Crawler {
 }
 
 impl Crawler {
-	pub fn new(networking_profile: config::ResolvedNetworkingProfile, tx_pp: Sender<ParserTask>) -> Crawler {
-		Crawler { networking_profile, parse_tx: tx_pp }
+	pub fn new(networking_profile: config::ResolvedNetworkingProfile, tx_pp: Arc<Sender<ParserTask>>) -> Crawler {
+		Crawler { networking_profile, tx_pp }
 	}
 
 	pub fn iter<JS: JobStateValues, TS: TaskStateValues, P: ParsedDocument>(
@@ -297,7 +297,7 @@ impl Crawler {
 		&self,
 		job: Job<JS, TS, P>,
 		update_tx: Sender<JobUpdate<JS, TS>>,
-	) -> PinnedTask {
+	) -> TaskFut {
 		TracingTask::new(span!(url=%job.url), async move {
 			let job = ResolvedJob::from(job);
 
@@ -311,7 +311,7 @@ impl Crawler {
 					job.clone(),
 					scheduler.job_update_tx.clone(),
 					scheduler.tasks_rx.clone(),
-					self.parse_tx.clone(),
+					(*self.tx_pp).clone(),
 					Box::new(client_factory.clone()),
 					Arc::clone(&self.networking_profile.resolver),
 					true,
@@ -340,7 +340,7 @@ impl Crawler {
 pub struct MultiCrawler<JS: JobStateValues, TS: TaskStateValues, P: ParsedDocument> {
 	job_rx:              Receiver<Job<JS, TS, P>>,
 	update_tx:           Sender<JobUpdate<JS, TS>>,
-	parse_tx:            Sender<ParserTask>,
+	tx_pp:               Arc<Sender<ParserTask>>,
 	concurrency_profile: config::ConcurrencyProfile,
 	networking_profile:  config::ResolvedNetworkingProfile,
 }
@@ -348,40 +348,37 @@ pub struct MultiCrawler<JS: JobStateValues, TS: TaskStateValues, P: ParsedDocume
 pub type MultiCrawlerTuple<JS, TS, P> = (MultiCrawler<JS, TS, P>, Sender<Job<JS, TS, P>>, Receiver<JobUpdate<JS, TS>>);
 impl<JS: JobStateValues, TS: TaskStateValues, P: ParsedDocument> MultiCrawler<JS, TS, P> {
 	pub fn new(
-		tx_pp: Sender<ParserTask>,
+		tx_pp: Arc<Sender<ParserTask>>,
 		concurrency_profile: config::ConcurrencyProfile,
 		networking_profile: config::ResolvedNetworkingProfile,
 	) -> MultiCrawlerTuple<JS, TS, P> {
 		let (job_tx, job_rx) = bounded_ch::<Job<JS, TS, P>>(concurrency_profile.job_tx_buffer_size());
 		let (update_tx, update_rx) = bounded_ch::<JobUpdate<JS, TS>>(concurrency_profile.job_update_buffer_size());
-		(
-			MultiCrawler { job_rx, update_tx, parse_tx: tx_pp, concurrency_profile, networking_profile },
-			job_tx,
-			update_rx,
-		)
+		(MultiCrawler { job_rx, update_tx, tx_pp, concurrency_profile, networking_profile }, job_tx, update_rx)
 	}
 
 	async fn process(self) -> Result<()> {
 		while let Ok(job) = self.job_rx.recv_async().await {
 			let np = self.networking_profile.clone();
 
+			let tx_pp = Arc::clone(&self.tx_pp);
 			if job.addrs.is_some() {
 				let np_static = ResolvedNetworkingProfile {
 					values:   np.values,
 					resolver: Arc::new(Box::new(AsyncStaticResolver::new(job.addrs.clone().unwrap().clone()))),
 				};
 
-				let crawler = Crawler::new(np_static, self.parse_tx.clone());
+				let crawler = Crawler::new(np_static, tx_pp);
 				let _ = crawler.go(job, self.update_tx.clone()).await;
 			} else {
-				let crawler = Crawler::new(np, self.parse_tx.clone());
+				let crawler = Crawler::new(np, tx_pp);
 				let _ = crawler.go(job, self.update_tx.clone()).await;
 			}
 		}
 		Ok(())
 	}
 
-	pub fn go(self) -> PinnedTask<'static> {
+	pub fn go(self) -> TaskFut<'static> {
 		TracingTask::new(span!(), async move {
 			let mut handles = vec![];
 			for _ in 0..self.concurrency_profile.domain_concurrency {
